add_adol_chu9d: Add adolescent CHU-9D

add_adol_chu9dR Documentation

Add adolescent CHU-9D

Description

add_adol_chu9d() is an Add function that updates an object by adding new values to new or empty fields. Specifically, this function implements an algorithm to add adolescent chu-9d. The function returns Dataset (a tibble).

Usage

add_adol_chu9d(
  ds_tb,
  adol_chu9d_scrg_ds = make_adol_chu9d_scrg_ds(),
  cleanse_1L_chr = c("all", "none", "dims", "items", "itemdims"),
  dim_pfx_1L_chr = "chu9d_dim",
  item_pfx_1L_chr = "chu9d_item",
  scale_by_1L_dbl = 1.1059,
  unweighted_1L_chr = "chu9d_cml",
  weighted_1L_chr = "chu9d_utl"
)

Arguments

ds_tb

Dataset (a tibble)

adol_chu9d_scrg_ds

PARAM_DESCRIPTION, Default: make_adol_chu9d_scrg_ds()

cleanse_1L_chr

Cleanse (a character vector of length one), Default: c("all", "none", "dims", "items", "itemdims")

dim_pfx_1L_chr

Dimension prefix (a character vector of length one), Default: 'chu9d_dim'

item_pfx_1L_chr

Item prefix (a character vector of length one), Default: 'chu9d_item'

scale_by_1L_dbl

Scale by (a double vector of length one), Default: 1.1059

unweighted_1L_chr

Unweighted (a character vector of length one), Default: 'chu9d_cml'

weighted_1L_chr

Weighted (a character vector of length one), Default: 'chu9d_utl'

Value

Dataset (a tibble)


ready4-dev/scorz documentation built on June 1, 2025, 2:07 p.m.