add_aqol4d_scores: Add AQoL-4D scores

add_aqol4d_scoresR Documentation

Add AQoL-4D scores

Description

add_aqol4d_scores() is an Add function that updates an object by adding new values to new or empty fields. Specifically, this function implements an algorithm to add aqol-4d scores. The function returns Object (an output object of multiple potential types).

Usage

add_aqol4d_scores(
  object_xx,
  country_1L_chr = NA_character_,
  itm_labels_chr = character(0),
  itm_prefix_1L_chr = "aqol4d_q",
  keep_all_1L_lgl = F,
  scrg_dss_ls = NULL,
  tot_unwtd_var_nm_1L_chr = "aqol4d_unwtd_dbl",
  utl_var_nm_1L_chr = "aqol4d_utl_dbl"
)

Arguments

object_xx

Object (an output object of multiple potential types)

country_1L_chr

Country (a character vector of length one), Default: 'NA'

itm_labels_chr

Item labels (a character vector), Default: character(0)

itm_prefix_1L_chr

Item prefix (a character vector of length one), Default: 'aqol4d_q'

keep_all_1L_lgl

Keep all (a logical vector of length one), Default: F

scrg_dss_ls

Scoring datasets (a list), Default: NULL

tot_unwtd_var_nm_1L_chr

Total unweighted variable name (a character vector of length one), Default: 'aqol4d_unwtd_dbl'

utl_var_nm_1L_chr

Utility variable name (a character vector of length one), Default: 'aqol4d_utl_dbl'

Value

Object (an output object of multiple potential types)


ready4-dev/scorz documentation built on June 1, 2025, 2:07 p.m.