add_item_totals: Add item totals

add_item_totalsR Documentation

Add item totals

Description

add_item_totals() is an Add function that updates an object by adding new values to new or empty fields. Specifically, this function implements an algorithm to add item totals. The function returns Dataset (a tibble).

Usage

add_item_totals(
  ds_tb,
  domains_ls = NULL,
  domains_prefix_1L_chr = character(0),
  domain_tfmn_fn = identity,
  items_prefix_1L_chr,
  total_var_nm_1L_chr,
  total_tfmn_fn = identity,
  type_fn = as.integer
)

Arguments

ds_tb

Dataset (a tibble)

domains_ls

Domains (a list), Default: NULL

domains_prefix_1L_chr

Domains prefix (a character vector of length one), Default: character(0)

domain_tfmn_fn

Domain transformation (a function), Default: identity

items_prefix_1L_chr

Items prefix (a character vector of length one)

total_var_nm_1L_chr

Total variable name (a character vector of length one)

total_tfmn_fn

Total transformation (a function), Default: identity

type_fn

Type (a function), Default: as.integer

Value

Dataset (a tibble)


ready4-dev/scorz documentation built on June 1, 2025, 2:07 p.m.