| make_adol_chu9d_scrg_ds | R Documentation |
make_adol_chu9d_scrg_ds() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make adolescent chu-9d scoring dataset. The function is called for its side effects and does not return a value.
make_adol_chu9d_scrg_ds()
Adolescent CHU-9D scoring (a dataset)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.