make_aqol4d_domain_qs_lup: Make AQoL-4D domain questions lookup table

make_aqol4d_domain_qs_lupR Documentation

Make AQoL-4D domain questions lookup table

Description

make_aqol4d_domain_qs_lup() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d domain questions lookup table. The function returns an AQoL-4D domain questions (a lookup table).

Usage

make_aqol4d_domain_qs_lup()

Value

an AQoL-4D domain questions (a lookup table)


ready4-dev/scorz documentation built on June 1, 2025, 2:07 p.m.