| make_aqol4d_domains_ls | R Documentation |
make_aqol4d_domains_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d domains list. The function returns Domains (a list).
make_aqol4d_domains_ls(domain_qs_lup = NULL)
domain_qs_lup |
Domain questions (a lookup table), Default: NULL |
Domains (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.