| make_aqol4d_item_disvalue_lup | R Documentation |
make_aqol4d_item_disvalue_lup() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d item disvalue lookup table. The function returns Item disvalue (a lookup table).
make_aqol4d_item_disvalue_lup()
Item disvalue (a lookup table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.