make_aqol4d_params_lup: Make AQoL-4D parameters lookup table

make_aqol4d_params_lupR Documentation

Make AQoL-4D parameters lookup table

Description

make_aqol4d_params_lup() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d parameters lookup table. The function returns an AQoL-4D parameters (a lookup table).

Usage

make_aqol4d_params_lup(domain_qs_lup = NULL)

Arguments

domain_qs_lup

Domain questions (a lookup table), Default: NULL

Value

an AQoL-4D parameters (a lookup table)


ready4-dev/scorz documentation built on June 1, 2025, 2:07 p.m.