| make_aqol4d_scrg_dss_ls | R Documentation |
make_aqol4d_scrg_dss_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d scoring datasets list. The function returns an AQoL-4D scoring datasets (a list).
make_aqol4d_scrg_dss_ls()
an AQoL-4D scoring datasets (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.