| make_aqol6d_item_nms | R Documentation |
make_aqol6d_item_nms() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make assessment of quality of life six dimension item names. The function returns Assessment of Quality of Life Six Dimension item names (a character vector).
make_aqol6d_item_nms()
Assessment of Quality of Life Six Dimension item names (a character vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.