| make_eq5d_dict | R Documentation |
make_eq5d_dict() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make eq5d dictionary. The function returns EQ5D dictionary (a ready4 submodule).
make_eq5d_dict()
EQ5D dictionary (a ready4 submodule)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.