scorz-package: scorz: Score Multi-Attribute Utility Instruments

scorz-packageR Documentation

scorz: Score Multi-Attribute Utility Instruments

Description

logo

Modules from the readyforwhatsnext youth mental health economic model (https://readyforwhatsnext.org/) that can be used to summarise multiple questionnaire responses in a single index measure. This package uses publicly available scoring algorithms to calculate health utility from multi-attribute utility instruments and has been developed with the ready4 framework (https://www.ready4-dev.com/). This development version of the scorz package has been made available as part of the process of testing and documenting the package. If you have any questions, please contact the authors (matthew.hamilton1@monash.edu).

logo

Modules from the readyforwhatsnext youth mental health economic model (https://readyforwhatsnext.org/) that can be used to summarise multiple questionnaire responses in a single index measure. This package uses publicly available scoring algorithms to calculate health utility from multi-attribute utility instruments and has been developed with the ready4 framework (https://www.ready4-dev.com/). This development version of the scorz package has been made available as part of the process of testing and documenting the package. If you have any questions, please contact the authors (matthew.hamilton1@monash.edu).

Author(s)

Maintainer: Matthew Hamilton matthew.hamilton1@monash.edu (ORCID) [copyright holder]

Authors:

Other contributors:

  • Orygen [copyright holder, funder]

  • Headspace [funder]

  • National Health and Medical Research Council [funder]

See Also

Useful links:

Useful links:


ready4-dev/scorz documentation built on June 1, 2025, 2:07 p.m.