| make_aqol4d_domain_qs_lup | R Documentation |
make_aqol4d_domain_qs_lup() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d domain questions lookup table. The function returns an AQoL-4D domain questions (a lookup table).
make_aqol4d_domain_qs_lup()
an AQoL-4D domain questions (a lookup table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.