| make_aqol4d_params_lup | R Documentation |
make_aqol4d_params_lup() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make aqol-4d parameters lookup table. The function returns an AQoL-4D parameters (a lookup table).
make_aqol4d_params_lup(domain_qs_lup = NULL)
domain_qs_lup |
Domain questions (a lookup table), Default: NULL |
an AQoL-4D parameters (a lookup table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.